// Initialize Chart.js
const ctx = document.getElementById('loss-chart').getContext('2d');
let chart = new Chart(ctx, {
  type: 'line',
  data: {
    labels: [],
    datasets: [{
      label: 'Training Loss',
      data: [],
      borderColor: '#4f46e5',
      backgroundColor: 'rgba(79, 70, 229, 0.1)',
      borderWidth: 2,
      fill: true
    }]
  },
  options: {
    responsive: true,
    maintainAspectRatio: false,
    scales: {
      x: {
        title: {
          display: true,
          text: 'Epochs'
        }
      },
      y: {
        title: {
          display: true,
          text: 'Loss'
        }
      }
    }
  }
});

// Update metrics display
function updateMetrics(auc, ks, logloss) {
  document.getElementById('auc').textContent = auc.toFixed(4);
  document.getElementById('ks').textContent = ks.toFixed(4);
  document.getElementById('logloss').textContent = logloss.toFixed(4);
}

// Update chart with new data
function updateChart(lossData) {
  chart.data.labels = lossData.map((_, i) => i + 1);
  chart.data.datasets[0].data = lossData;
  chart.update();
}

// Run experiment
document.getElementById('run-experiment').addEventListener('click', async () => {
  const config = {
    innerUnits: parseInt(document.getElementById('inner-units').value),
    outerUnits: parseInt(document.getElementById('outer-units').value),
    gridPoints: parseInt(document.getElementById('grid-points').value),
    splineDegree: parseInt(document.getElementById('spline-degree').value),
    learningRate: parseFloat(document.getElementById('learning-rate').value),
    epochs: parseInt(document.getElementById('epochs').value),
    attentionType: document.getElementById('attention-type').value
  };

  // Simulate API call
  const response = await fetch('/api/experiment', {
    method: 'POST',
    headers: {
      'Content-Type': 'application/json'
    },
    body: JSON.stringify(config)
  });

  const data = await response.json();
  
  // Update UI with results
  updateMetrics(data.auc, data.ks, data.logloss);
  updateChart(data.lossHistory);
});